Data Reduction
=================

.. currentmodule:: pynrc

.. autosummary::
   :toctree: _autosummary
   :template: custom-module-template.rst
   :recursive:
   
   reduce.calib
   reduce.ref_pixels
